@@ -104,14 +104,14 @@ cluster <-
            con.ragin <-
              function(X, Y)
              {
-               sum(apply(cbind(X, Y), 1, min) )/sum(X)
+               (sum(apply(cbind(X, Y), 1, min) )+1e-10)/(sum(X)+1e-10)
              }
            #	Pooled consistency suff.
            con.pool <-
              function(x, y)
              {
                z <- cbind(as.vector(x), as.vector(y))
-               sum(apply(z, 1, min))/sum(x)
+               (sum(apply(z, 1, min))+1e-10)/(sum(x)+1e-10)
              }
            #	Between consistency suff.
            con.betw <-
@@ -129,14 +129,14 @@ cluster <-
            cvr.ragin <-
              function(X, Y)
              {
-               sum(apply(cbind(X, Y), 1, min))/sum(Y)
+               (sum(apply(cbind(X, Y), 1, min))+1e-10)/(sum(Y)+1e-10)
              }
            #	Pooled coverage suff.
            cvr.pool <-
              function(x, y)
              {
                z <- cbind(as.vector(x), as.vector(y))
-               sum(apply(z, 1, min))/sum(y)
+               (sum(apply(z, 1, min))+1e-10)/(sum(y)+1e-10)
              }
            #	Between coverage suff.
            cvr.betw <-
@@ -159,7 +159,7 @@ cluster <-
                {
                  J <- ncol(X)
                  bc <- con.betw(X, Y)
-                 sqrt(sum(((bc/sum(bc)) - (1/J))^p))
+                 sqrt(sum((((bc+1e-10)/(sum(bc)+1e-10)) - (1/J))^p))
                }
              #	d(Within, Pooled), Euclidean for p=2
              dWP <-
@@ -167,7 +167,7 @@ cluster <-
                {
                  N <- nrow(X)
                  wc <- con.with(X, Y)
-                 sqrt(sum(((wc/sum(wc)) - (1/N))^p))
+                 sqrt(sum((((wc+1e-10)/(sum(wc)+1e-10)) - (1/N))^p))
                }}
            else{
              #	d(Between, Pooled), Euclidean for p=2
@@ -176,7 +176,7 @@ cluster <-
                {
                  J <- ncol(X)
                  bc <- cvr.betw(X, Y)
-                 sqrt(sum(((bc/sum(bc)) - (1/J))^p))
+                 sqrt(sum((((bc+1e-10)/(sum(bc)+1e-10)) - (1/J))^p))
                }
              #	d(Within, Pooled), Euclidean for p=2
              dWP <-
@@ -184,7 +184,7 @@ cluster <-
                {
                  N <- nrow(X)
                  wc <- cvr.with(X, Y)
-                 sqrt(sum(((wc/sum(wc)) - (1/N))^p))
+                 sqrt(sum((((wc+1e-10)/(sum(wc)+1e-10)) - (1/N))^p))
                }
            }
            # Nr of cases in clusters and units:
@@ -299,14 +299,14 @@ cluster <-
               con.ragin <-
                 function(X, Y)
                 {
-                  sum(apply(cbind(X, Y), 1, min))/sum(X)
+                  (sum(apply(cbind(X, Y), 1, min))+1e-10)/(sum(X)+1e-10)
                 }
               #	Pooled consistency suff.
               con.pool <-
                 function(x, y)
                 {
                   z <- cbind(as.vector(x), as.vector(y))
-                  sum(apply(z, 1, min))/sum(x)
+                  (sum(apply(z, 1, min))+1e-10)/(sum(x)+1e-10)
                 }
               #	Between consistency suff.
               con.betw <-
@@ -324,14 +324,14 @@ cluster <-
               cvr.ragin <-
                 function(X, Y)
                 {
-                  sum(apply(cbind(X, Y), 1, min))/sum(Y)
+                  (sum(apply(cbind(X, Y), 1, min))+1e-10)/(sum(Y)+1e-10)
                 }
               #	Pooled coverage suff.
               cvr.pool <-
                 function(x, y)
                 {
                   z <- cbind(as.vector(x), as.vector(y))
-                  sum(apply(z, 1, min))/sum(y)
+                  (sum(apply(z, 1, min))+1e-10)/(sum(y)+1e-10)
                 }
               #	Between coverage suff.
               cvr.betw <-
@@ -354,7 +354,7 @@ cluster <-
                   {
                     J <- ncol(X)
                     bc <- con.betw(X, Y)
-                    sqrt(sum(((bc/sum(bc)) - (1/J))^p))
+                    sqrt(sum((((bc+1e-10)/(sum(bc)+1e-10)) - (1/J))^p))
                   }
                 #	d(Within, Pooled), Euclidean for p=2
                 dWP <-
@@ -362,7 +362,7 @@ cluster <-
                   {
                     N <- nrow(X)
                     wc <- con.with(X, Y)
-                    sqrt(sum(((wc/sum(wc)) - (1/N))^p))
+                    sqrt(sum((((wc+1e-10)/(sum(wc)+1e-10)) - (1/N))^p))
                   }}
               else{
                 #	d(Between, Pooled), Euclidean for p=2
@@ -371,7 +371,7 @@ cluster <-
                   {
                     J <- ncol(X)
                     bc <- cvr.betw(X, Y)
-                    sqrt(sum(((bc/sum(bc)) - (1/J))^p))
+                    sqrt(sum((((bc+1e-10)/(sum(bc)+1e-10)) - (1/J))^p))
                   }
                 #	d(Within, Pooled), Euclidean for p=2
                 dWP <-
@@ -379,7 +379,7 @@ cluster <-
                   {
                     N <- nrow(X)
                     wc <- cvr.with(X, Y)
-                    sqrt(sum(((wc/sum(wc)) - (1/N))^p))
+                    sqrt(sum((((wc+1e-10)/(sum(wc)+1e-10)) - (1/N))^p))
                   }
               }
               
@@ -427,5 +427,5 @@ cluster <-
               return(r)
           }}
       }
-}
+  }
 
