@@ -48,7 +48,7 @@ rob.ncutrange <-
                                            n.cut = n.cut.tl,
                                            include = include,
                                            ...)), silent = TRUE)
-      if (class(sol) == "try-error") {break}
+      if ("try-error" %in% class(sol)) {break}
       if (is.null(init.sol$i.sol)) {
         s = sol$solution[[1]]
       }
@@ -89,7 +89,7 @@ rob.ncutrange <-
                                            n.cut = n.cut.tu,
                                            include = include,
                                            ...)), silent = TRUE)
-      if (class(sol) == "try-error") {break}
+      if ("try-error" %in% class(sol)) {break}
       if (is.null(init.sol$i.sol)) {
         s = sol$solution[[1]]
       }
